@@ -83,6 +83,7 @@ describe 'trove::keystone::authtoken' do
           :memcache_security_strategy           => 'ENCRYPT',
           :memcache_use_advanced_pool           => true,
           :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
+          :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :revocation_cache_time                => '11',
           :signing_dir                          => '/var/cache',
@@ -127,6 +128,10 @@ describe 'trove::keystone::authtoken' do
         is_expected.to contain_trove_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_trove_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
+
+      it 'installs python memcache package' do
+        is_expected.to contain_package('python-memcache')
+      end
     end
   end
 
